// Main style
import "./../sass/rw-makelaar.scss";

// Lightgallery
import lightGallery from 'lightgallery'
import lgThumbnail from 'lightgallery/plugins/thumbnail'

import 'lightgallery/scss/lightgallery.scss'
import 'lightgallery/scss/lg-transitions.scss'
import 'lightgallery/scss/lg-thumbnail.scss'

/**
 * INIT FUNCTION
 ====================================================== */
(function($) {

    'use strict';

    window.RW_Makelaar = {

        // Settings
        $window: $(window),
        $body: $('body'),
        licenseKey : '', // LightGallery license key

        // Initialise the object
        // ---------------------------------------------- /
        init: function() {
            this.RW_ReadMore('.read-more--active');
            this.RW_Gallery();
            this.RW_Filter();
            this.RW_Project();
        },

        // Gallery
        // ---------------------------------------------- /
        RW_Gallery: function() {
            const self = this;

            // House images
            if(typeof houseImages !== 'undefined') {
                const $houseGalleryBtn = document.getElementsByClassName('house-header__open-gallery');

                const houseGallery = lightGallery($houseGalleryBtn[0], {
                    licenseKey  : self.licenseKey,
                    plugins: [lgThumbnail],
                    dynamic: true,
                    dynamicEl: houseImages,
                    thumbnail: true,
                    download: false,
                    mobileSettings : {
                        showCloseIcon: true
                    }
                });

                $('.house-image-1').on('click', function () {
                    houseGallery.openGallery(0);
                });
                $('.house-image-2').on('click', function () {
                    houseGallery.openGallery(1);
                });
                $('.house-image-3').on('click', function () {
                    houseGallery.openGallery(2);
                });
            }

        },

        // Read more
        // ---------------------------------------------- /
        RW_ReadMore: function(el, num = 10) {
            const $readMores = $(el);
            if($readMores.length < 1) return;

            $readMores.each(function( index ) {

                const $readMore = $(this);
                const activeClass = 'read-more--active';
                const $readMoreBtn = $readMore.find('.read-more__btn');

                const readMoreText = $readMoreBtn.text();
                const readLessText = $readMoreBtn.data('text-less');

                $readMoreBtn.on('click', function () {

                    if ($readMore.hasClass(activeClass)) {
                        $readMoreBtn.text(readLessText);
                        $readMore.removeClass(activeClass);
                    } else {
                        $readMore.addClass(activeClass);
                        $readMoreBtn.text(readMoreText);
                    }

                });
            });
        },

        // Houses
        // ---------------------------------------------- /
        RW_Filter: function() {
            let openFilterLabel = '';
            const openClass = 'rw-btn-more-filter--open';
            const openBodyClass = 'rw-filter-open';

            // More handler for the extended filter
            $('.rw-btn-more-filter').on( 'click', function() {
                const $btn = $(this);
                if(openFilterLabel === '') {
                    openFilterLabel = $btn.text();
                }
                const closeFilterLabel = $btn.data('close-label');

                if($btn.hasClass(openClass)){
                    $btn.removeClass(openClass);
                    $('body').removeClass(openBodyClass);
                    $btn.text(openFilterLabel);
                } else {
                    $btn.addClass(openClass);
                    $('body').addClass(openBodyClass);
                    $btn.text(closeFilterLabel);
                }

                $('.rw-search-form').toggleClass( 'rw-search-form--more-filter-open' );
            });

            // Close extended filter on mobile
            $('.rw-search-form-collapse-trigger').on( 'click', function() {
                $(this).toggleClass( 'rw-search-form-collapse-trigger--open' );
                $('.rw-search-form').toggleClass( 'rw-search-form--open' );
            });

            // Show more options if has children (like filter Soort aanbod)
            $('.rw-search-field__checkbox--has-children .rw-search-field__checkbox-input-main').on( 'click', function() {
                $(this).closest('.rw-search-field__checkbox-main').toggleClass('rw-search-field__checkbox--children-active');
            });
        },

        // Project
        // ---------------------------------------------- /
        RW_Project: function() {

            let $previousSelectedGrid = null;
            const $projectTypes = $('.grid-project-types');
            if( $projectTypes.length < 1 ) return;

            $( '.grid-project-types__col' ).on( 'click', '.grid-house-item', function() {
                const $gridInner = $(this);
                const $grid = $gridInner.parent();
                const projectID = $grid.data('project-id');

                if($previousSelectedGrid != null) {
                    $previousSelectedGrid.css('paddingBottom', 0);
                }

                $projectTypes.find( '.grid-project-types__col').removeClass('list-project-houses-visible');

                const $activeType = $projectTypes.find( '.list-project-houses[data-project-id="'+projectID+'"]' );

                if($activeType.length > 0) {
                    $grid.css('paddingBottom', $activeType.outerHeight());
                    $grid.addClass('list-project-houses-visible');
                }

                $previousSelectedGrid = $grid;
            });

        }
    };

})(jQuery);

RW_Makelaar.init();