<?php
/**
 * VARIABLES
 * ============================================================================== */
define( 'THEME_DIR', get_template_directory_uri() );
define( 'HOME_PAGE_ID', get_option( 'page_on_front' ) );

/**
 * THEME
 * ============================================================================== */
class MainTheme {

	const THEME_VERSION = '2.0.0';

	public function __construct() {
		$this->add_actions();
	}

	/**
	 * Actions & filters
	 */
	public function add_actions() {
		add_action( 'wp_enqueue_scripts', [ $this, 'load_build' ], 99 );
		add_action( 'init', [ $this, 'register_menus' ] );
		add_action( 'init', [ $this, 'register_posttypes' ] );
		add_action( 'widgets_init', [ $this, 'register_sidebars' ] );
		add_action( 'after_setup_theme', [ $this, 'theme_support' ] );
	}

	/**
	 * Load assets
	 *
	 * @return void
	 */
	public function load_build() {

		if( wp_get_environment_type() === 'local' ) {
			$path = THEME_DIR . '/dev';
		} else {
			$path = THEME_DIR . '/dist';
		}

		// Cleanup
		wp_dequeue_style( 'wp-block-library' );
		wp_dequeue_style( 'wc-block-style' );
		wp_dequeue_style( 'wp-block-library-theme' );
		wp_dequeue_style( 'global-styles' ); // REMOVE THEME.JSON

		// Main
        wp_enqueue_style( 'main-theme-style', $path.'/app.css', [], self::THEME_VERSION );
		wp_enqueue_script('main-theme-script',  $path.'/app.js', [ 'jquery' ], self::THEME_VERSION, true );
		wp_localize_script( 'main-theme-script', 'vars', array(
			'ajaxurl' => admin_url( 'admin-ajax.php' )
		));

		// RW makelaar
		wp_enqueue_style( 'rw-makelaar-style', $path.'/rw_makelaar.css', [], self::THEME_VERSION );
		wp_enqueue_script('rw-makelaar-script',  $path.'/rw_makelaar.js', [ 'jquery' ], self::THEME_VERSION, true );

	}

	/**
	 * Register menus
	 *
	 * @return void
	 */
	public function register_menus() {
		register_nav_menus( array(
			'main-menu'     => __( 'Hoofdmenu' ),
		) );
	}

	public function register_posttypes() {}

	public function register_sidebars() {}

	public function theme_support() {

		if( wp_get_environment_type() === 'local' ) {
			$style = 'dev/editor.css';
		} else {
			$style = 'dist/editor.css';
		}
        // Admin editor style
        add_editor_style( $style );

        // Theme support
		add_theme_support( 'post-thumbnails' );
	}

	/**
	 * Get SVG icon HTML
	 *
	 * @param $icon
	 * @param $args
	 *
	 * @return string
	 */
	public static function get_svg_icon( $icon, $args = [] ) {
		$output = '';

		$args = shortcode_atts([
			'title'     => '',
			'width'     => '',
			'height'    => '',
			'url'       => '',
			'aria_label'=> ''
		], $args, 'get_svg_icon' );

		if( !empty( $args['url'] ) ) {
			$output .= '<a href="'.esc_url( $args['url'] ).'" '.( !empty( $args['aria_label'] ) ? 'aria_label="'.esc_attr( $args['aria_label'] ).'"' : '' ).'>';
		}

		$output .= '<img width="'.$args['width'].'" height="'.$args['height'].'" src="'.THEME_DIR.'/assets/images/icon-'.esc_attr( $icon ).'.svg" alt="'.esc_attr( $args['title'] ).'" />';

		if( !empty( $args['url'] )) {
			$output .= '</a>';
		}

		return $output;
	}
}
new MainTheme();